@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require "spec_helper"
 
 describe Tmuxinator::Cli do
@@ -15,7 +17,7 @@ describe Tmuxinator::Cli do
       File.new(local_project_path, "w").tap do |f|
         f.write content
       end.close
-      expect(File.exists?(local_project_path)).to be_truthy
+      expect(File.exist?(local_project_path)).to be_truthy
       expect(File.read(local_project_path)).to eq content
     end
 
@@ -26,7 +28,7 @@ describe Tmuxinator::Cli do
 
   subject(:cli) { described_class }
 
-  let(:fixtures_dir) { File.expand_path("../../../fixtures/", __FILE__) }
+  let(:fixtures_dir) { File.expand_path("../../fixtures", __dir__) }
   let(:project) { FactoryBot.build(:project) }
   let(:project_config) do
     File.join(fixtures_dir, "sample_with_project_config.yml")
@@ -93,7 +95,7 @@ describe Tmuxinator::Cli do
         context "a tmuxinator project name" do
           before do
             expect(Tmuxinator::Config).to \
-              receive(:exists?).with(name: arg1) { true }
+              receive(:exist?).with(name: arg1) { true }
           end
 
           it "should call #start" do
@@ -127,7 +129,7 @@ describe Tmuxinator::Cli do
         context "something else" do
           before do
             expect(Tmuxinator::Config).to \
-              receive(:exists?).with(name: arg1) { false }
+              receive(:exist?).with(name: arg1) { false }
           end
 
           it "should call ::start" do
@@ -622,7 +624,7 @@ describe Tmuxinator::Cli do
   describe "#copy" do
     before do
       ARGV.replace(["copy", "foo", "bar"])
-      allow(Tmuxinator::Config).to receive(:exists?) { true }
+      allow(Tmuxinator::Config).to receive(:exist?) { true }
     end
 
     context "new project already exists" do
@@ -638,7 +640,7 @@ describe Tmuxinator::Cli do
 
     context "existing project doesn't exist" do
       before do
-        allow(Tmuxinator::Config).to receive(:exists?) { false }
+        allow(Tmuxinator::Config).to receive(:exist?) { false }
       end
 
       it "exit with error code" do
@@ -714,7 +716,7 @@ describe Tmuxinator::Cli do
 
       context "project exists" do
         before do
-          allow(Tmuxinator::Config).to receive(:exists?) { true }
+          allow(Tmuxinator::Config).to receive(:exist?) { true }
         end
 
         it "deletes the project" do
@@ -725,7 +727,7 @@ describe Tmuxinator::Cli do
 
       context "local project exists" do
         before do
-          allow(Tmuxinator::Config).to receive(:exists?) { true }
+          allow(Tmuxinator::Config).to receive(:exist?) { true }
           expect(Tmuxinator::Config).to receive(:project) { "local" }
         end
 
@@ -737,7 +739,7 @@ describe Tmuxinator::Cli do
 
       context "project doesn't exist" do
         before do
-          allow(Tmuxinator::Config).to receive(:exists?) { false }
+          allow(Tmuxinator::Config).to receive(:exist?) { false }
         end
 
         it "outputs an error message" do
@@ -754,7 +756,7 @@ describe Tmuxinator::Cli do
 
       context "all projects exist" do
         before do
-          allow(Tmuxinator::Config).to receive(:exists?).and_return(true)
+          allow(Tmuxinator::Config).to receive(:exist?).and_return(true)
         end
 
         it "deletes the projects" do
@@ -765,10 +767,10 @@ describe Tmuxinator::Cli do
 
       context "only one project exists" do
         before do
-          allow(Tmuxinator::Config).to receive(:exists?).with(name: "foo") {
+          allow(Tmuxinator::Config).to receive(:exist?).with(name: "foo") {
             true
           }
-          allow(Tmuxinator::Config).to receive(:exists?).with(name: "bar") {
+          allow(Tmuxinator::Config).to receive(:exist?).with(name: "bar") {
             false
           }
         end
@@ -785,7 +787,7 @@ describe Tmuxinator::Cli do
 
       context "all projects do not exist" do
         before do
-          allow(Tmuxinator::Config).to receive(:exists?).and_return(false)
+          allow(Tmuxinator::Config).to receive(:exist?).and_return(false)
         end
 
         it "outputs multiple error messages" do
@@ -952,7 +954,7 @@ describe Tmuxinator::Cli do
     let(:name) { "sample" }
     let(:custom_name) { nil }
     let(:cli_options) { {} }
-    let(:path) { File.expand_path("../../../fixtures", __FILE__) }
+    let(:path) { File.expand_path("../../fixtures", __dir__) }
 
     shared_examples_for :a_proper_project do
       it "should create a valid project" do
